[−][src]Struct email_format::rfc5322::headers::OptionalField
Fields
name: FieldNamevalue: UnstructuredTrait Implementations
impl Clone for OptionalField[src]
fn clone(&self) -> OptionalField[src]
fn clone_from(&mut self, source: &Self)1.0.0[src]
impl Debug for OptionalField[src]
impl Display for OptionalField[src]
impl Parsable for OptionalField[src]
impl PartialEq<OptionalField> for OptionalField[src]
fn eq(&self, other: &OptionalField) -> bool[src]
fn ne(&self, other: &OptionalField) -> bool[src]
impl Streamable for OptionalField[src]
impl StructuralPartialEq for OptionalField[src]
impl<'a, 'b> TryFrom<(&'a [u8], &'b [u8])> for OptionalField[src]
type Error = ParseError
The type returned in the event of a conversion error.
fn try_from(input: (&'a [u8], &'b [u8])) -> Result<OptionalField, ParseError>[src]
impl<'a, 'b> TryFrom<(&'a str, &'b str)> for OptionalField[src]
type Error = ParseError
The type returned in the event of a conversion error.
fn try_from(input: (&'a str, &'b str)) -> Result<OptionalField, ParseError>[src]
impl<'a> TryFrom<(FieldName, Unstructured)> for OptionalField[src]
type Error = ParseError
The type returned in the event of a conversion error.
fn try_from(
input: (FieldName, Unstructured)
) -> Result<OptionalField, ParseError>[src]
input: (FieldName, Unstructured)
) -> Result<OptionalField, ParseError>